pub struct BuildConfig { /* private fields */ }Expand description
config for building tailwind
// example
BuildConfig::new().with_cdn_src("https://my.cdn.com").build()?;Implementations
Sourceimpl BuildConfig
impl BuildConfig
Sourcepub fn with_tailwind_package(self, version: impl Into<String>) -> Self
pub fn with_tailwind_package(self, version: impl Into<String>) -> Self
specify the tailwind cli package to use
default: @tailwindcss/cli@4.3.0
Sourcepub fn with_path(self, p: Option<impl AsRef<Path>>) -> Self
pub fn with_path(self, p: Option<impl AsRef<Path>>) -> Self
changes the path from which the css file is loaded
specifying a file makes it required
specifying None looks for a style.css file
at the root of of the project
if the file does not exist it uses the the default:
@import "tailwindcss";
@source "src/**/*.{rs,html,js}";Sourcepub fn with_cdn_src(self, s: impl Into<String>) -> Self
pub fn with_cdn_src(self, s: impl Into<String>) -> Self
specifies the cdn used as a source for the jit builds